var servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules =
[
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "com::sun::star::container::XIndexReplace", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#a30efc34ee46bcbd9bdcdc5fad23706b3", null ],
    [ "DefaultListId", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#ae1283571b6eec1e8879cad4010d56cfa", null ],
    [ "IsAbsoluteMargins", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#a890f4747830984ac83c1c9e31f54cc91", null ],
    [ "IsAutomatic", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#aef8673876c856dba7a150226a26bc77d", null ],
    [ "IsContinuousNumbering", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#a0aea01cdbe0ad2f04fcb78f82237b422", null ],
    [ "Name", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#a7ee9065718e6628dc7791b756fa6c0f9", null ],
    [ "NumberingIsOutline", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#a8531518389e5f485b01cd4efc1758459", null ],
    [ "NumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html#ae3dc42096fd541eb9a8b3c3e0654582b", null ]
];